@@ -3,12 +3,9 @@ import subprocess
 import sys
 from pathlib import Path
 
-from .conftest import needs_py39
-
 root_path = Path(__file__).parent.parent
 
 
-@needs_py39
 def test_select_gen() -> None:
     env = os.environ.copy()
     env["CHECK_JINJA"] = "1"
